@@ -1,5 +1,5 @@
 from .style import Style
 from .stylesheet import StyleSheet
-from .units import Unit, pt, em, pc, px, rem
+from .units import Unit, pt, em, fr, px, rem, pc
 from .color import Color
 from .selector import Selector
